==> open-cluster-management-policy-model-6.5.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementDecisionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementDecisionFluentImpl<A extends PlacementDecisionFluent<A>> extends BaseFluent<A> implements PlacementDecisionFluent<A>{
  public PlacementDecisionFluentImpl() {
  }
  public PlacementDecisionFluentImpl(PlacementDecision instance) {
    this.withClusterName(instance.getClusterName()); 
    this.withClusterNamespace(instance.getClusterNamespace()); 
  }
  private String clusterName;
  private String clusterNamespace;
  public String getClusterName() {
    return this.clusterName;
  }
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  public Boolean hasClusterName() {
    return this.clusterName != null;
  }
  public String getClusterNamespace() {
    return this.clusterNamespace;
  }
  public A withClusterNamespace(String clusterNamespace) {
    this.clusterNamespace=clusterNamespace; return (A) this;
  }
  public Boolean hasClusterNamespace() {
    return this.clusterNamespace != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PlacementDecisionFluentImpl that = (PlacementDecisionFluentImpl) o;
    if (clusterName != null ? !clusterName.equals(that.clusterName) :that.clusterName != null) return false;
    if (clusterNamespace != null ? !clusterNamespace.equals(that.clusterNamespace) :that.clusterNamespace != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  clusterNamespace,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (clusterNamespace != null) { sb.append("clusterNamespace:"); sb.append(clusterNamespace); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementDecisionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementDecisionFluentImpl<A extends PlacementDecisionFluent<A>> extends BaseFluent<A> implements PlacementDecisionFluent<A>{
  public PlacementDecisionFluentImpl() {
  }
  public PlacementDecisionFluentImpl(PlacementDecision instance) {
    if (instance != null) {
      this.withClusterName(instance.getClusterName());
      this.withClusterNamespace(instance.getClusterNamespace());
    }
  }
  private String clusterName;
  private String clusterNamespace;
  public String getClusterName() {
    return this.clusterName;
  }
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  public Boolean hasClusterName() {
    return this.clusterName != null;
  }
  public String getClusterNamespace() {
    return this.clusterNamespace;
  }
  public A withClusterNamespace(String clusterNamespace) {
    this.clusterNamespace=clusterNamespace; return (A) this;
  }
  public Boolean hasClusterNamespace() {
    return this.clusterNamespace != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementDecisionFluentImpl that = (PlacementDecisionFluentImpl) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;

    if (!java.util.Objects.equals(clusterNamespace, that.clusterNamespace)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  clusterNamespace,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (clusterNamespace != null) { sb.append("clusterNamespace:"); sb.append(clusterNamespace); }
    sb.append("}");
    return sb.toString();
  }
  
}
